==> config_editor-1.0.3-fix.1%2B1.21.5-sources.jar: io/github/zhengzhengyiyi/ConfigEditorClient.java <==
package io.github.zhengzhengyiyi;

import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import io.github.zhengzhengyiyi.api.ApiEntrypoint;
import io.github.zhengzhengyiyi.gui.EditorScreen;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import java.util.List;
import java.util.ArrayList;

public class ConfigEditorClient implements ClientModInitializer {
	public static String MOD_ID = "config_editor";
	
	/**
	 * The keybinding for open the configure
	 * @see class_304
	 */
	public static class_304 key = KeyBindingHelper.registerKeyBinding(new class_304(
			"zhengzhengyiyi.key.open_gui",
			class_3675.class_307.field_1668,
			GLFW.GLFW_KEY_UNKNOWN,
			"key.category.zhengzhengyiyi"
	));
	/**
	 * The Logger for the other mod's entry point, usually for printing errors.
	 */
	public static Logger API_ENTRYPOINT_LOGGER = LoggerFactory.getLogger("api_entry_point");
	
	/**
	 * The Logger for the whole mod.
	 */
	public static Logger LOGGER = LoggerFactory.getLogger(MOD_ID);
	
	/**
	 * 
	 * put every api entry point into a List
	 * 
	 * @see List
	 */
	public static final List<ApiEntrypoint> ENTRYPOINTS = new ArrayList<>();
	
	@Override
	public void onInitializeClient() {
		FabricLoader.getInstance()
        .getEntrypointContainers(MOD_ID, ApiEntrypoint.class)
        .forEach(entrypoint -> {
            String modId = entrypoint.getProvider().getMetadata().getId();
            try {
            	entrypoint.getEntrypoint().init();
            	
            	ENTRYPOINTS.add(entrypoint.getEntrypoint());
            } catch (Throwable e) {
            	API_ENTRYPOINT_LOGGER.error("Mod '{}' has a broken 'config_editor' entrypoint implementation.", modId, e);
            }
        });
		
		ENTRYPOINTS.add(new UndoRedoEntrypoint());
		
		ClientTickEvents.END_CLIENT_TICK.register((client) -> {
			if (key.method_1434()) {
				client.method_1507(new EditorScreen());
			}
		});
	}
}

==> config_editor-1.0.4-fix.1%2B1.21.5-sources.jar: io/github/zhengzhengyiyi/ConfigEditorClient.java <==
package io.github.zhengzhengyiyi;

import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import io.github.zhengzhengyiyi.addon.DateTimeDisplayEntrypoint;
import io.github.zhengzhengyiyi.addon.TextStatsEntrypoint;
import io.github.zhengzhengyiyi.addon.UndoRedoEntrypoint;
import io.github.zhengzhengyiyi.api.ApiEntrypoint;
import io.github.zhengzhengyiyi.gui.EditorScreen;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import java.util.List;
import java.util.ArrayList;

public class ConfigEditorClient implements ClientModInitializer {
	public static String MOD_ID = "config_editor";
	
	/**
	 * The keybinding for open the configure
	 * @see class_304
	 */
	public static class_304 key = KeyBindingHelper.registerKeyBinding(new class_304(
			"zhengzhengyiyi.key.open_gui",
			class_3675.class_307.field_1668,
			GLFW.GLFW_KEY_UNKNOWN,
			"key.category.zhengzhengyiyi"
	));
	/**
	 * The Logger for the other mod's entry point, usually for printing errors.
	 */
	public static Logger API_ENTRYPOINT_LOGGER = LoggerFactory.getLogger("api_entry_point");
	
	/**
	 * The Logger for the whole mod.
	 */
	public static Logger LOGGER = LoggerFactory.getLogger(MOD_ID);
	
	/**
	 * 
	 * put every api entry point into a List
	 * 
	 * @see List
	 */
	public static final List<ApiEntrypoint> ENTRYPOINTS = new ArrayList<>();
	
	@Override
	public void onInitializeClient() {
		FabricLoader.getInstance()
        .getEntrypointContainers(MOD_ID, ApiEntrypoint.class)
        .forEach(entrypoint -> {
            String modId = entrypoint.getProvider().getMetadata().getId();
            try {
            	entrypoint.getEntrypoint().init();
            	
            	ENTRYPOINTS.add(entrypoint.getEntrypoint());
            } catch (Throwable e) {
            	API_ENTRYPOINT_LOGGER.error("Mod '{}' has a broken 'config_editor' entrypoint implementation.", modId, e);
            }
        });
		
		ENTRYPOINTS.add(new UndoRedoEntrypoint());
		ENTRYPOINTS.add(new TextStatsEntrypoint());
		ENTRYPOINTS.add(new DateTimeDisplayEntrypoint());
		
		ClientTickEvents.END_CLIENT_TICK.register((client) -> {
			if (key.method_1434()) {
				client.method_1507(new EditorScreen());
			}
		});
	}
}
